[aXSL-commit] SF.net SVN: axsl:[2991] trunk/axsl/axsl-primitive/src /main/java/org/axsl/primitive/s
An API for XSL-FO.
Status: Alpha
Brought to you by:
victormote
|
From: <vic...@us...> - 2026-03-25 15:00:22
|
Revision: 2991
http://sourceforge.net/p/axsl/code/2991
Author: victormote
Date: 2026-03-25 15:00:20 +0000 (Wed, 25 Mar 2026)
Log Message:
-----------
Handle long as well as int and short when appending integrals.
Modified Paths:
--------------
trunk/axsl/axsl-primitive/src/main/java/org/axsl/primitive/sequence/ByteSequenceMutable.java
Modified: trunk/axsl/axsl-primitive/src/main/java/org/axsl/primitive/sequence/ByteSequenceMutable.java
===================================================================
--- trunk/axsl/axsl-primitive/src/main/java/org/axsl/primitive/sequence/ByteSequenceMutable.java 2026-03-09 00:13:11 UTC (rev 2990)
+++ trunk/axsl/axsl-primitive/src/main/java/org/axsl/primitive/sequence/ByteSequenceMutable.java 2026-03-25 15:00:20 UTC (rev 2991)
@@ -116,12 +116,16 @@
ByteSequenceMutable append(char theChar, Charset charset);
/**
* Converts an integer to the ASCII bytes of its String representation, and appends them to this sequence.
* For example, the integer 418 will be converted to the bytes 0x343138.
- * @param theInteger The int to be converted and appended.
+ * The method {@link #append(byte)} <em>does not</em> do any such conversion, but appends the raw byte to the
+ * sequence.
+ * @param theLong The integral to be converted and appended.
* @return A reference to this.
+ * @see #append(byte)
*/
- ByteSequenceMutable append(int theInteger);
+ ByteSequenceMutable append(long theLong);
/**
* Appends the content of an input stream.
This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.
@@ -116,12 +116,16 @@
ByteSequenceMutable append(char theChar, Charset charset);
/**
- * Converts an integer to the ASCII bytes of its String representation, and appends them to this sequence.
+ * Converts any integral (long, int, short) except {@link Byte#TYPE} to the ASCII bytes of its String
+ * representation, and appends them to this sequence.
* For example, the integer 418 will be converted to the bytes 0x343138.
|